macro_rules! py_module_add_function {
($mod:ident, $mod_name:literal, $fn:ident) => { ... };
}Expand description
Macro to register a function to a Python module.
macro_rules! py_module_add_function {
($mod:ident, $mod_name:literal, $fn:ident) => { ... };
}Macro to register a function to a Python module.